from hyde.plugin import Plugin
import gzip

class GzipperPlugin(Plugin):
    """
    A Hyde plugin for putting gzipped versions alongside output resources.
    Default configuration:

    gzipper:
        extensions:
            - html
            - css
            - js
    """

    def begin_site(self):
        self.files = []
        try:
            self.exts = set(self.site.config.gzipper.extensions)
        except AttributeError:
            self.exts = set(['html', 'css', 'js'])

    def text_resource_complete(self, resource, text):
        self.binary_resource_complete(resource)
        return text

    def binary_resource_complete(self, resource):
        deploy_path = self.site.config.deploy_root_path.child(resource.get_relative_deploy_path())
        ext = deploy_path.rsplit('.', 1)[-1]
        if ext in self.exts:
            self.files.append(deploy_path)

    def generation_complete(self):
        for deploy_path in self.files:
            self.logger.debug('Gzipping resource path [%s]' % (deploy_path,))
            with open(deploy_path, 'rb') as source:
                with gzip.open(deploy_path + '.gz', 'wb') as target:
                    while True:
                        data = source.read(1<<20)
                        if not data: break
                        target.write(data)




#!/usr/bin/env python
# Bootstrap installation of Distribute
import distribute_setup
distribute_setup.use_setuptools()

from setuptools import setup, find_packages
from gzipper.version import __version__


PROJECT = 'hyde-gzipper'
try:
    long_description = open('README.rst', 'rt').read()
except IOError:
    long_description = ''


setup(name=PROJECT,
      version=__version__,
      description='Hyde plugin for gzipping files',
      long_description = long_description,
      author='Radek Czajka',
      author_email='rczajka@rczajka.pl',
      url='http://rczajka.pl/hyde-gzipper',
      packages=find_packages(),
      requires=['python (>= 2.7)'],
      license='MIT',
      classifiers=[
            'Development Status :: 1 - Planning',
            'Environment :: Plugins',
            'Intended Audience :: Developers',
            'Intended Audience :: System Administrators',
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python',
            'Topic :: Internet :: WWW/HTTP :: Site Management',
        ],
      zip_safe=True,
)
